#!/usr/bin/perl 
#===============================================================================
#
#         FILE:  check_multi_procs.pl
#
#        USAGE:  ./check_multi_procs.pl  
#
#  DESCRIPTION:  Check multiple process with check_procs plugin nagios
#				 Note : This module is deprecated if you use last version of check_procs
#
#      OPTIONS:  ---
# REQUIREMENTS:  ---
#         BUGS:  ---
#        NOTES:  ---
#       AUTHOR:  Pierre Mavro (), pierre@mavro.fr
#      COMPANY:  
#      VERSION:  1.0
#      CREATED:  10/12/2009 16:47:47
#     REVISION:  ---
#
# Config Example :
# check_command      check_nrpe!check_multi_procs!user!"proc1:proc2:proc3"
#===============================================================================

use strict;
use warnings;
use Getopt::Long;

# Global vars
my $check_proc_bin='/opt/csw/libexec/nagios-plugins/check_procs';

# Help print
sub help
{
    print "Usage : ./check_multi_procs.pl -f filer -u user [-b check_proc_bin] [-s min_proc] [-x max_proc] [-h]\n";
    print "\t-u : Set user owner of process\n";
    print "\t-f : Give process to check (must be string and could be separated by ';')\n";
    print "\t-b : Specify the check_proc Nagios plugin binary\n";
    print "\t-s : Set min process to be available (default 1)\n";
    print "\t-x : Set max process to be available (default 1)\n";
    print "\t-h : Print this help message\n";
    exit(1);
}

# Check all process
sub check_all_procs
{
	my $check_proc_bin=shift;
	my $min=shift;
	my $max=shift;
	my $user=shift;
	my $filters=shift;
	my @errors;
	my @all_filters;
	my @current_filter;
	
	foreach (@$filters)
	{
		@current_filter = split /:/, $_;
		foreach (@current_filter)
		{
			push @all_filters, $_;
		}
	}
	
	# Push errors to @errors array
	foreach (@all_filters)
	{
		open (CHECK_PROC_OUTPUT, "$check_proc_bin -c $min:$max -u $user -a $_ |");
		while (<CHECK_PROC_OUTPUT>)
		{
			unless (/PROCS OK/i)
			{
				chomp $_;
				push @errors, $_;
			}
		}
		close (CHECK_PROC_OUTPUT);
	}
	
	# Print to nagios OK or the errors
	if (@errors)
	{
		print "Multiple process check failed on :\n";
		foreach (@errors)
		{
			print "$_\n";
		}
        exit(2);
	}
	else
	{
		print "Multiple process check OK\n";
        exit(0);
	}
}

# Command Args
sub check_opts
{
	# Vars
	my $user;
	my @filters;
	my $min=1;
	my $max=1;
	
	# Set options
	GetOptions( "help|h"    => \&help,
				"f=s"       => \@filters,
				"u=s"		=> \$user,
				"s=i"		=> \$min,
				"x=i"		=> \$max,
				"b=s"		=> \$check_proc_bin);
				
	unless ((@filters) and ($user))
	{
		&help;
	}
	else
	{
		die "Problem with $check_proc_bin binary : $!\n" unless (-x $check_proc_bin);
		&check_all_procs($check_proc_bin,$min,$max,$user,\@filters);
	}
}

&check_opts;